#!/bin/sh
BASE_DIR=$(realpath $(dirname $0))
cd $BASE_DIR
ROOT=$PWD
if [ "$1" = "--summary" ]; then
  OUTPUT=$BASE_DIR/output.log
  cat /dev/null > $OUTPUT
else
  OUTPUT=/dev/stdout
fi
echo ; echo Running tests in android
echo ========================================
cd android
./run.sh
cd $ROOT
echo ; echo Running tests in bpf
echo ========================================
cd bpf
(./test_verifier >> $OUTPUT 2>&1 && echo "selftests: test_verifier [PASS]") || echo "selftests: test_verifier [FAIL]"
(./test_tag >> $OUTPUT 2>&1 && echo "selftests: test_tag [PASS]") || echo "selftests: test_tag [FAIL]"
(./test_maps >> $OUTPUT 2>&1 && echo "selftests: test_maps [PASS]") || echo "selftests: test_maps [FAIL]"
(./test_lru_map >> $OUTPUT 2>&1 && echo "selftests: test_lru_map [PASS]") || echo "selftests: test_lru_map [FAIL]"
(./test_lpm_map >> $OUTPUT 2>&1 && echo "selftests: test_lpm_map [PASS]") || echo "selftests: test_lpm_map [FAIL]"
(./test_progs >> $OUTPUT 2>&1 && echo "selftests: test_progs [PASS]") || echo "selftests: test_progs [FAIL]"
(./test_align >> $OUTPUT 2>&1 && echo "selftests: test_align [PASS]") || echo "selftests: test_align [FAIL]"
(./test_verifier_log >> $OUTPUT 2>&1 && echo "selftests: test_verifier_log [PASS]") || echo "selftests: test_verifier_log [FAIL]"
(./test_dev_cgroup >> $OUTPUT 2>&1 && echo "selftests: test_dev_cgroup [PASS]") || echo "selftests: test_dev_cgroup [FAIL]"
(./test_tcpbpf_user >> $OUTPUT 2>&1 && echo "selftests: test_tcpbpf_user [PASS]") || echo "selftests: test_tcpbpf_user [FAIL]"
(./test_kmod.sh >> $OUTPUT 2>&1 && echo "selftests: test_kmod.sh [PASS]") || echo "selftests: test_kmod.sh [FAIL]"
(./test_libbpf.sh >> $OUTPUT 2>&1 && echo "selftests: test_libbpf.sh [PASS]") || echo "selftests: test_libbpf.sh [FAIL]"
(./test_xdp_redirect.sh >> $OUTPUT 2>&1 && echo "selftests: test_xdp_redirect.sh [PASS]") || echo "selftests: test_xdp_redirect.sh [FAIL]"
(./test_xdp_meta.sh >> $OUTPUT 2>&1 && echo "selftests: test_xdp_meta.sh [PASS]") || echo "selftests: test_xdp_meta.sh [FAIL]"
(./test_offload.py >> $OUTPUT 2>&1 && echo "selftests: test_offload.py [PASS]") || echo "selftests: test_offload.py [FAIL]"
cd $ROOT
echo ; echo Running tests in breakpoints
echo ========================================
cd breakpoints
(./step_after_suspend_test >> $OUTPUT 2>&1 && echo "selftests: step_after_suspend_test [PASS]") || echo "selftests: step_after_suspend_test [FAIL]"
(./breakpoint_test >> $OUTPUT 2>&1 && echo "selftests: breakpoint_test [PASS]") || echo "selftests: breakpoint_test [FAIL]"
cd $ROOT
echo ; echo Running tests in capabilities
echo ========================================
cd capabilities
(./test_execve >> $OUTPUT 2>&1 && echo "selftests: test_execve [PASS]") || echo "selftests: test_execve [FAIL]"
cd $ROOT
echo ; echo Running tests in cpufreq
echo ========================================
cd cpufreq
(./main.sh >> $OUTPUT 2>&1 && echo "selftests: main.sh [PASS]") || echo "selftests: main.sh [FAIL]"
cd $ROOT
echo ; echo Running tests in cpu-hotplug
echo ========================================
cd cpu-hotplug
(./cpu-on-off-test.sh >> $OUTPUT 2>&1 && echo "selftests: cpu-on-off-test.sh [PASS]") || echo "selftests: cpu-on-off-test.sh [FAIL]"
cd $ROOT
echo ; echo Running tests in efivarfs
echo ========================================
cd efivarfs
(./efivarfs.sh >> $OUTPUT 2>&1 && echo "selftests: efivarfs.sh [PASS]") || echo "selftests: efivarfs.sh [FAIL]"
cd $ROOT
echo ; echo Running tests in exec
echo ========================================
cd exec
(./execveat >> $OUTPUT 2>&1 && echo "selftests: execveat [PASS]") || echo "selftests: execveat [FAIL]"
cd $ROOT
echo ; echo Running tests in firmware
echo ========================================
cd firmware
(./fw_filesystem.sh >> $OUTPUT 2>&1 && echo "selftests: fw_filesystem.sh [PASS]") || echo "selftests: fw_filesystem.sh [FAIL]"
(./fw_fallback.sh >> $OUTPUT 2>&1 && echo "selftests: fw_fallback.sh [PASS]") || echo "selftests: fw_fallback.sh [FAIL]"
cd $ROOT
echo ; echo Running tests in ftrace
echo ========================================
cd ftrace
(./ftracetest >> $OUTPUT 2>&1 && echo "selftests: ftracetest [PASS]") || echo "selftests: ftracetest [FAIL]"
cd $ROOT
echo ; echo Running tests in futex
echo ========================================
cd futex
./run.sh
cd $ROOT
echo ; echo Running tests in gpio
echo ========================================
cd gpio
(./gpio-mockup.sh >> $OUTPUT 2>&1 && echo "selftests: gpio-mockup.sh [PASS]") || echo "selftests: gpio-mockup.sh [FAIL]"
cd $ROOT
echo ; echo Running tests in intel_pstate
echo ========================================
cd intel_pstate
(./run.sh >> $OUTPUT 2>&1 && echo "selftests: run.sh [PASS]") || echo "selftests: run.sh [FAIL]"
cd $ROOT
echo ; echo Running tests in ipc
echo ========================================
cd ipc
(./msgque >> $OUTPUT 2>&1 && echo "selftests: msgque [PASS]") || echo "selftests: msgque [FAIL]"
cd $ROOT
echo ; echo Running tests in kcmp
echo ========================================
cd kcmp
(./kcmp_test >> $OUTPUT 2>&1 && echo "selftests: kcmp_test [PASS]") || echo "selftests: kcmp_test [FAIL]"
cd $ROOT
echo ; echo Running tests in lib
echo ========================================
cd lib
(./printf.sh >> $OUTPUT 2>&1 && echo "selftests: printf.sh [PASS]") || echo "selftests: printf.sh [FAIL]"
(./bitmap.sh >> $OUTPUT 2>&1 && echo "selftests: bitmap.sh [PASS]") || echo "selftests: bitmap.sh [FAIL]"
cd $ROOT
echo ; echo Running tests in membarrier
echo ========================================
cd membarrier
(./membarrier_test >> $OUTPUT 2>&1 && echo "selftests: membarrier_test [PASS]") || echo "selftests: membarrier_test [FAIL]"
cd $ROOT
echo ; echo Running tests in memfd
echo ========================================
cd memfd
(./run_tests.sh >> $OUTPUT 2>&1 && echo "selftests: run_tests.sh [PASS]") || echo "selftests: run_tests.sh [FAIL]"
cd $ROOT
echo ; echo Running tests in memory-hotplug
echo ========================================
cd memory-hotplug
./mem-on-off-test.sh -r 2 && echo selftests: memory-hotplug [PASS] || echo selftests: memory-hotplug [FAIL]
cd $ROOT
echo ; echo Running tests in mount
echo ========================================
cd mount
if [ -f /proc/self/uid_map ] ; then ./unprivileged-remount-test ; else echo WARN: No /proc/self/uid_map exist, test skipped. ; fi
cd $ROOT
echo ; echo Running tests in mqueue
echo ========================================
cd mqueue
./mq_open_tests /test1 || echo "selftests: mq_open_tests [FAIL]"
./mq_perf_tests || echo "selftests: mq_perf_tests [FAIL]"
cd $ROOT
echo ; echo Running tests in net
echo ========================================
cd net
(./reuseport_bpf >> $OUTPUT 2>&1 && echo "selftests: reuseport_bpf [PASS]") || echo "selftests: reuseport_bpf [FAIL]"
(./reuseport_bpf_cpu >> $OUTPUT 2>&1 && echo "selftests: reuseport_bpf_cpu [PASS]") || echo "selftests: reuseport_bpf_cpu [FAIL]"
(./reuseport_bpf_numa >> $OUTPUT 2>&1 && echo "selftests: reuseport_bpf_numa [PASS]") || echo "selftests: reuseport_bpf_numa [FAIL]"
(./reuseport_dualstack >> $OUTPUT 2>&1 && echo "selftests: reuseport_dualstack [PASS]") || echo "selftests: reuseport_dualstack [FAIL]"
(./reuseaddr_conflict >> $OUTPUT 2>&1 && echo "selftests: reuseaddr_conflict [PASS]") || echo "selftests: reuseaddr_conflict [FAIL]"
(./run_netsocktests >> $OUTPUT 2>&1 && echo "selftests: run_netsocktests [PASS]") || echo "selftests: run_netsocktests [FAIL]"
(./run_afpackettests >> $OUTPUT 2>&1 && echo "selftests: run_afpackettests [PASS]") || echo "selftests: run_afpackettests [FAIL]"
(./test_bpf.sh >> $OUTPUT 2>&1 && echo "selftests: test_bpf.sh [PASS]") || echo "selftests: test_bpf.sh [FAIL]"
(./netdevice.sh >> $OUTPUT 2>&1 && echo "selftests: netdevice.sh [PASS]") || echo "selftests: netdevice.sh [FAIL]"
(./rtnetlink.sh >> $OUTPUT 2>&1 && echo "selftests: rtnetlink.sh [PASS]") || echo "selftests: rtnetlink.sh [FAIL]"
(./fib_tests.sh >> $OUTPUT 2>&1 && echo "selftests: fib_tests.sh [PASS]") || echo "selftests: fib_tests.sh [FAIL]"
cd $ROOT
echo ; echo Running tests in nsfs
echo ========================================
cd nsfs
(./owner >> $OUTPUT 2>&1 && echo "selftests: owner [PASS]") || echo "selftests: owner [FAIL]"
(./pidns >> $OUTPUT 2>&1 && echo "selftests: pidns [PASS]") || echo "selftests: pidns [FAIL]"
cd $ROOT
echo ; echo Running tests in powerpc
echo ========================================
cd powerpc
cd $ROOT
echo ; echo Running tests in pstore
echo ========================================
cd pstore
(./pstore_tests >> $OUTPUT 2>&1 && echo "selftests: pstore_tests [PASS]") || echo "selftests: pstore_tests [FAIL]"
(./pstore_post_reboot_tests >> $OUTPUT 2>&1 && echo "selftests: pstore_post_reboot_tests [PASS]") || echo "selftests: pstore_post_reboot_tests [FAIL]"
cd $ROOT
echo ; echo Running tests in ptrace
echo ========================================
cd ptrace
(./peeksiginfo >> $OUTPUT 2>&1 && echo "selftests: peeksiginfo [PASS]") || echo "selftests: peeksiginfo [FAIL]"
cd $ROOT
echo ; echo Running tests in seccomp
echo ========================================
cd seccomp
(./seccomp_bpf >> $OUTPUT 2>&1 && echo "selftests: seccomp_bpf [PASS]") || echo "selftests: seccomp_bpf [FAIL]"
(./seccomp_benchmark >> $OUTPUT 2>&1 && echo "selftests: seccomp_benchmark [PASS]") || echo "selftests: seccomp_benchmark [FAIL]"
cd $ROOT
echo ; echo Running tests in sigaltstack
echo ========================================
cd sigaltstack
(./sas >> $OUTPUT 2>&1 && echo "selftests: sas [PASS]") || echo "selftests: sas [FAIL]"
cd $ROOT
echo ; echo Running tests in size
echo ========================================
cd size
(./get_size >> $OUTPUT 2>&1 && echo "selftests: get_size [PASS]") || echo "selftests: get_size [FAIL]"
cd $ROOT
echo ; echo Running tests in splice
echo ========================================
cd splice
(./default_file_splice_read.sh >> $OUTPUT 2>&1 && echo "selftests: default_file_splice_read.sh [PASS]") || echo "selftests: default_file_splice_read.sh [FAIL]"
cd $ROOT
echo ; echo Running tests in static_keys
echo ========================================
cd static_keys
(./test_static_keys.sh >> $OUTPUT 2>&1 && echo "selftests: test_static_keys.sh [PASS]") || echo "selftests: test_static_keys.sh [FAIL]"
cd $ROOT
echo ; echo Running tests in sync
echo ========================================
cd sync
(./sync_test >> $OUTPUT 2>&1 && echo "selftests: sync_test [PASS]") || echo "selftests: sync_test [FAIL]"
cd $ROOT
echo ; echo Running tests in sysctl
echo ========================================
cd sysctl
(./sysctl.sh >> $OUTPUT 2>&1 && echo "selftests: sysctl.sh [PASS]") || echo "selftests: sysctl.sh [FAIL]"
cd $ROOT
echo ; echo Running tests in timers
echo ========================================
cd timers
(./posix_timers >> $OUTPUT 2>&1 && echo "selftests: posix_timers [PASS]") || echo "selftests: posix_timers [FAIL]"
(./nanosleep >> $OUTPUT 2>&1 && echo "selftests: nanosleep [PASS]") || echo "selftests: nanosleep [FAIL]"
(./nsleep-lat >> $OUTPUT 2>&1 && echo "selftests: nsleep-lat [PASS]") || echo "selftests: nsleep-lat [FAIL]"
(./set-timer-lat >> $OUTPUT 2>&1 && echo "selftests: set-timer-lat [PASS]") || echo "selftests: set-timer-lat [FAIL]"
(./mqueue-lat >> $OUTPUT 2>&1 && echo "selftests: mqueue-lat [PASS]") || echo "selftests: mqueue-lat [FAIL]"
(./inconsistency-check >> $OUTPUT 2>&1 && echo "selftests: inconsistency-check [PASS]") || echo "selftests: inconsistency-check [FAIL]"
(./raw_skew >> $OUTPUT 2>&1 && echo "selftests: raw_skew [PASS]") || echo "selftests: raw_skew [FAIL]"
(./threadtest >> $OUTPUT 2>&1 && echo "selftests: threadtest [PASS]") || echo "selftests: threadtest [FAIL]"
(./rtctest >> $OUTPUT 2>&1 && echo "selftests: rtctest [PASS]") || echo "selftests: rtctest [FAIL]"
cd $ROOT
echo ; echo Running tests in user
echo ========================================
cd user
(./test_user_copy.sh >> $OUTPUT 2>&1 && echo "selftests: test_user_copy.sh [PASS]") || echo "selftests: test_user_copy.sh [FAIL]"
cd $ROOT
echo ; echo Running tests in vm
echo ========================================
cd vm
(./run_vmtests >> $OUTPUT 2>&1 && echo "selftests: run_vmtests [PASS]") || echo "selftests: run_vmtests [FAIL]"
cd $ROOT
echo ; echo Running tests in x86
echo ========================================
cd x86
(./single_step_syscall_64 >> $OUTPUT 2>&1 && echo "selftests: single_step_syscall_64 [PASS]") || echo "selftests: single_step_syscall_64 [FAIL]"
(./sysret_ss_attrs_64 >> $OUTPUT 2>&1 && echo "selftests: sysret_ss_attrs_64 [PASS]") || echo "selftests: sysret_ss_attrs_64 [FAIL]"
(./syscall_nt_64 >> $OUTPUT 2>&1 && echo "selftests: syscall_nt_64 [PASS]") || echo "selftests: syscall_nt_64 [FAIL]"
(./test_mremap_vdso_64 >> $OUTPUT 2>&1 && echo "selftests: test_mremap_vdso_64 [PASS]") || echo "selftests: test_mremap_vdso_64 [FAIL]"
(./check_initial_reg_state_64 >> $OUTPUT 2>&1 && echo "selftests: check_initial_reg_state_64 [PASS]") || echo "selftests: check_initial_reg_state_64 [FAIL]"
(./sigreturn_64 >> $OUTPUT 2>&1 && echo "selftests: sigreturn_64 [PASS]") || echo "selftests: sigreturn_64 [FAIL]"
(./iopl_64 >> $OUTPUT 2>&1 && echo "selftests: iopl_64 [PASS]") || echo "selftests: iopl_64 [FAIL]"
(./mpx-mini-test_64 >> $OUTPUT 2>&1 && echo "selftests: mpx-mini-test_64 [PASS]") || echo "selftests: mpx-mini-test_64 [FAIL]"
(./ioperm_64 >> $OUTPUT 2>&1 && echo "selftests: ioperm_64 [PASS]") || echo "selftests: ioperm_64 [FAIL]"
(./protection_keys_64 >> $OUTPUT 2>&1 && echo "selftests: protection_keys_64 [PASS]") || echo "selftests: protection_keys_64 [FAIL]"
(./test_vdso_64 >> $OUTPUT 2>&1 && echo "selftests: test_vdso_64 [PASS]") || echo "selftests: test_vdso_64 [FAIL]"
(./test_vsyscall_64 >> $OUTPUT 2>&1 && echo "selftests: test_vsyscall_64 [PASS]") || echo "selftests: test_vsyscall_64 [FAIL]"
(./fsgsbase_64 >> $OUTPUT 2>&1 && echo "selftests: fsgsbase_64 [PASS]") || echo "selftests: fsgsbase_64 [FAIL]"
(./sysret_rip_64 >> $OUTPUT 2>&1 && echo "selftests: sysret_rip_64 [PASS]") || echo "selftests: sysret_rip_64 [FAIL]"
cd $ROOT
echo ; echo Running tests in zram
echo ========================================
cd zram
(./zram.sh >> $OUTPUT 2>&1 && echo "selftests: zram.sh [PASS]") || echo "selftests: zram.sh [FAIL]"
cd $ROOT
